"""
pdftools Package.

:author: Stefan Lehmann <stlm@posteo.de>
:license: MIT, see license file or https://opensource.org/licenses/MIT

:created on 2018-04-14 20:35:21
:last modified by:   Stefan Lehmann
:last modified time: 2018-10-28 16:57:24

"""
__version__ = "2.0.0"


from .pdftools import (
    pdf_merge,
    pdf_rotate,
    pdf_split,
    pdf_zip,
    pdf_insert,
    pdf_remove,
    pdf_add,
)
